@@ -127,7 +127,9 @@ class ExcelRegionParser(Parser):
         :return: Iterator over all the rows found in the excel.
         """
         self.reader.select_worksheet(self.region.sheet)
-        header_column = addr2index(f"{self.region.header.column}1")[1]
+        header_column = None
+        if self.region.header.column!="index":
+            header_column = addr2index(f"{self.region.header.column}1")[1]
         header_row = self.region.header.row
         from_row, from_col = addr2index(self.region.range.start)
         to_row, to_col = addr2index(self.region.range.end)
@@ -137,9 +139,12 @@ class ExcelRegionParser(Parser):
             range(from_row, to_row + 1), range(from_col, to_col + 1)
         ):
             val = self.get_value(row=row, col=col)
+            column_header = None
+            if header_column is None:
+                column_header = str(row)
             if val:
                 d = {
-                    "column_header": self.get_value(row=row, col=header_column),
+                    "column_header": column_header or self.get_value(row=row, col=header_column),
                     "row_header": self.get_value(row=header_row, col=col),
                     "value": val,
                     **literals,
